@@ -1,16 +1,12 @@
 from __future__ import annotations
 
-from logging import info
-
-from selenium.common.exceptions import ElementNotSelectableException
-from selenium.webdriver.remote.webelement import WebElement as SeleniumWebElement
-
 from dyatel.base.element import Element
+from dyatel.mixins.internal_utils import WAIT_EL
 
 
 class CoreCheckbox(Element):
 
-    def __init__(self, locator: str, locator_type='', name='', parent=None, wait=False, by_attr=False):
+    def __init__(self, locator: str, locator_type='', name='', parent=None, wait=False):
         """
         Initializing of core checkbox with appium/selenium driver
 
@@ -19,21 +15,19 @@ class CoreCheckbox(Element):
         :param name: name of element (will be attached to logs)
         :param parent: parent of element. Can be Web/MobileElement, Web/MobilePage or Group objects etc.
         :param wait: add element waiting in `wait_page_loaded` function of CorePage
-        :param by_attr: get is_checked state by custom attribute
         """
         super().__init__(locator=locator, locator_type=locator_type, name=name, parent=parent, wait=wait)
-        self.checked = None
-        self.by_attr = by_attr
 
-    @property
-    def element(self) -> SeleniumWebElement:
+    def wait_element(self, timeout: int = WAIT_EL, silent: bool = False):
         """
-        Get selenium WebElement object
+        Wait for current element available in DOM
 
-        :return: selenium WebElement
+        :param: timeout: time to stop waiting
+        :param: silent: erase log
+        :return: self
         """
         self.wait_availability(silent=True)
-        return self._get_element(wait=False)
+        return self
 
     def is_checked(self) -> bool:
         """
@@ -41,12 +35,7 @@ class CoreCheckbox(Element):
 
         :return: bool
         """
-        try:
-            is_checked_selenium = self.element.is_selected()
-        except ElementNotSelectableException:
-            is_checked_selenium = False
-
-        return self.checked if self.by_attr else is_checked_selenium
+        return self.element.is_selected()
 
     def check(self) -> CoreCheckbox:
         """
@@ -54,10 +43,13 @@ class CoreCheckbox(Element):
 
         :return: self
         """
-        if not self.is_checked():
-            info(f'Select "{self.name}"')
-            self.wait_clickable(silent=True).element.click()
-            self.checked = True
+        self.element = self._get_element()
+
+        try:
+            if not self.is_checked():
+                self.click()
+        finally:
+            self.element = None
 
         return self
 
@@ -67,18 +59,22 @@ class CoreCheckbox(Element):
 
         :return: self
         """
-        if self.is_checked():
-            info(f'Unselect "{self.name}"')
-            self.wait_clickable(silent=True).element.click()
-            self.checked = False
+        self.element = self._get_element()
+
+        try:
+            if self.is_checked():
+                self.click()
+        finally:
+            self.element = None
 
         return self
 
     @property
-    def get_text(self) -> str:
+    def text(self) -> str:
         """
         Get text of current checkbox
 
         :return: checkbox text
         """
-        return self.element.text if self.element.text else self.element.get_attribute('value')
+        element = self.element
+        return element.text if element.text else element.get_attribute('value')
