@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-from logging import info
 from typing import Union, List, Any
 
 from dyatel.dyatel_sel.core.core_element import CoreElement
@@ -31,7 +30,7 @@ class WebElement(CoreElement):
 
         :return: list of wrapped objects
         """
-        selenium_elements = self._get_driver().find_elements(self.locator_type, self.locator)
+        selenium_elements = self._find_elements(self._get_base())
         return self._get_all_elements(selenium_elements, WebElement)
 
     def hover(self) -> WebElement:
@@ -40,7 +39,7 @@ class WebElement(CoreElement):
 
         :return: self
         """
-        info(f'Hover over :{self.name}"')
+        self.log(f'Hover over "{self.name}"')
         self._action_chains\
             .move_to_element(self.element)\
             .move_by_offset(1, 1)\
@@ -48,15 +47,19 @@ class WebElement(CoreElement):
             .perform()
         return self
 
-    def hover_outside(self, x: int = -100, y: int = -100) -> WebElement:
+    def hover_outside(self, x: int = 0, y: int = -5) -> WebElement:
         """
         Hover outside from current element
 
+        :param x: x-offset of element to hover
+        :param y: y-offset of element to hover
         :return: self
         """
-        info(f'Hover outside from "{self.name}"')
+        self.log(f'Hover outside from "{self.name}"')
+
+        x, y = calculate_coordinate_to_click(self, x, y)
         self._action_chains\
-            .move_by_offset(x, y)\
+            .move_to_location(x, y)\
             .perform()
         return self
 
@@ -64,14 +67,21 @@ class WebElement(CoreElement):
         """
         Click outside of element. By default, 1px above and 1px left of element
 
-        :param x: x offset
-        :param y: y offset
+        :param x: x offset of element to click
+        :param y: y offset of element to click
         :return: self
         """
-        self.wait_element(silent=True)
-        dx, dy = calculate_coordinate_to_click(self, x, y)
-        self._action_chains\
-            .move_to_element_with_offset(self.element, dx, dy)\
-            .click()\
-            .perform()
+        self.log(f'Click outside from "{self.name}"')
+
+        x, y = calculate_coordinate_to_click(self, x, y)
+
+        self.driver_wrapper.click_by_coordinates(x=x, y=y, silent=True)
         return self
+
+    def get_rect(self) -> dict:
+        """
+        A dictionary with the size and location of the element.
+
+        :return: dict
+        """
+        return self.element.rect
