@@ -81,7 +81,7 @@ def get_child_elements_with_names(obj: object, instance: type) -> dict:
     return elements
 
 
-def calculate_coordinate_to_click(element: Any, x: int, y: int) -> tuple:
+def calculate_coordinate_to_click(element: Any, x: int = 0, y: int = 0) -> tuple:
     """
     Calculate coordinates to click for element
     Examples:
@@ -95,9 +95,8 @@ def calculate_coordinate_to_click(element: Any, x: int, y: int) -> tuple:
     :param y: vertical offset relative to either top (y > 0) or bottom side (y < 0)
     :return: tuple of calculated coordinates
     """
-    selenium_element = element.element
-    ex, ey = element.driver.execute_script(get_element_position_on_screen_js, selenium_element).values()
-    ew, eh = selenium_element.size.values()
+    el_rect = element.get_rect()
+    ex, ey, ew, eh = el_rect['x'], el_rect['y'], el_rect['width'], el_rect['height']
     emx, emy = ex + ew / 2, ey + eh / 2  # middle of element
 
     if x:
